==> 0.0.10.tar.gz: lib/command_executor.dart <==
import 'package:jt_flutter_cli/feature/add_api_call/api_call_cli.dart';
import 'package:jt_flutter_cli/feature/create_assets/create_assets_cli.dart';
import 'package:jt_flutter_cli/feature/create_feature/create_feature_cli.dart';
import 'package:jt_flutter_cli/feature/create_model/create_model_cli.dart';
import 'package:jt_flutter_cli/feature/create_widget/create_widget_cli.dart';

class CommandExecutor {
  /// create new feature
  static void createFeature({
    required String featureName,
  }) =>
      CreateFeature().createNewFeature(
        featureName,
      );

  /// create widget
  static void createWidget({
    required String widgetName,
  }) =>
      CreateWidget().createWidget(
        widgetName: widgetName,
      );

  /// create model
  static void createModel({
    required String modelName,
    required String featureName,
    required String jsonFilePath,
  }) =>
      CreateModel().generateDartModel(
        modelName: modelName,
        featureName: featureName,
        jsonFilePath: jsonFilePath,
      );

  /// add api call
  static void generateApiCallCode({
    required String apiMethod,
    required String apiEndPoint,
    required String apiName,
  }) =>
      AddAPI().generateApiCallCode(
        apiMethod: apiMethod,
        apiEndPoint: apiEndPoint,
        apiName: apiName,
      );

  ///Generate assets
  static void generateAssets({
    required String inputImagePath,
    required String imageToSaveDirectoryName,
  }) {
    GenerateAsset().generateAssets(
      inputImagePath: inputImagePath,
      imageToSaveDirectoryName: imageToSaveDirectoryName,
    );
  }
}

==> 1.0.0.tar.gz: lib/command_executor.dart <==
import 'package:jt_flutter_cli/feature/add_api_call/api_call_cli.dart';
import 'package:jt_flutter_cli/feature/create_assets/create_assets_cli.dart';
import 'package:jt_flutter_cli/feature/create_feature/create_feature_cli.dart';
import 'package:jt_flutter_cli/feature/create_model/create_model_cli.dart';
import 'package:jt_flutter_cli/feature/create_widget/create_widget_cli.dart';

class CommandExecutor {
  /// create new feature
  static Future<void> createFeature({
    required String featureName,
  }) async =>
      await CreateFeature().createNewFeature(
        featureName: featureName,
      );

  /// create widget
  static Future<void> createWidget({
    required String widgetName,
  }) async =>
      await CreateWidget().createWidget(
        widgetName: widgetName,
      );

  /// create model
  static void createModel({
    required String modelName,
    required String featureName,
    required String jsonFilePath,
  }) =>
      CreateModel().generateDartModel(
        modelName: modelName,
        featureName: featureName,
        jsonFilePath: jsonFilePath,
        isModelForAPI: false,
      );

  /// add api call
  static Future<void> generateApiCallCode({
    required String apiMethod,
    required String apiEndPoint,
    required String apiName,
  }) async =>
      await AddAPI().generateApiCallCode(
        apiMethod: apiMethod,
        apiEndPoint: apiEndPoint,
        apiName: apiName,
      );

  ///Generate assets
  static void generateAssets({
    required String inputImagePath,
    required String imageToSaveDirectoryName,
  }) {
    GenerateAsset().generateAssets(
      inputImagePath: inputImagePath,
      imageToSaveDirectoryName: imageToSaveDirectoryName,
    );
  }
}
